import { EventEmitter, OnInit, ElementRef, Renderer2 } from '@angular/core';
import { TextTreeNodeModel, TreeNodeModel } from '../models';
/**
 * The TreeNodeModel class represents a single TreeNodeModel for the treeview. Actually, this renders the real UI.
 *
 * The component needs this input value:
 *
 * * @Input() node: AcTextTreeNode;
 *
 * The several options are set through the AcTreeNodeOptions object that is being held by the
 * AcTextTreeNode class. This includes colors, icons, and other styles.
 *
 * The component can fire these events:
 *
 * * @Output() nodeClick: EventEmitter<AcTreeNode>;
 * * @Output() checkChanged: EventEmitter<AcTreeNode>;
 * * @Output() selectedChanged: EventEmitter<AcTreeNode>;
 * * @Output() collapseChanged: EventEmitter<AcTreeNode>;
 *
 */
export declare class TreeViewNodeComponent implements OnInit {
    private el;
    private renderer;
    constructor(el: ElementRef, renderer: Renderer2);
    private static pfxIcon;
    private static opnIcon;
    private static clsIcon;
    /**
     * The object that controls the node's appearance.
     */
    node: TextTreeNodeModel;
    /**
     * Fired on click and hence fired even if any of the other parts are being fired.
     */
    nodeClick: EventEmitter<TreeNodeModel>;
    /**
     * Fired if a checkable field is being clicked.
     */
    checkChanged: EventEmitter<TreeNodeModel>;
    /**
     * Fired if a selectable field is being clicked.
     */
    selectedChanged: EventEmitter<TreeNodeModel>;
    /**
     * Fired if a node collapses or expands.
     */
    collapseChanged: EventEmitter<TreeNodeModel>;
    href: string;
    collapseClasses: Array<string>;
    iconClasses: Array<string>;
    foreColor: string;
    backColor: string;
    isExpanded: boolean;
    private preSelectState;
    ngOnInit(): void;
    onNodeClick(node: TreeNodeModel): void;
    onCheckChanged(node: TreeNodeModel): void;
    onSelectedChanged(node: TreeNodeModel): void;
    onCollapseChanged(node: TreeNodeModel): void;
    handleCheckChange(): void;
    handleClick($event: any): void;
    handleCollapse(): void;
    handlePreSelection(state: boolean): void;
    handleSelection($event: any): void;
}
